package edu.georgetown.gucs.tokenizers;

import java.util.Collections;
import java.util.List;
import java.util.StringTokenizer;
import java.util.Vector;

import edu.georgetown.gucs.utility.Token;

/**
 * Eliminates tokens from headers in the Enron data set
 * 
 * @author Clay Shields
 * @author Lindsay Neubauer
 * 
 */
public class EnronStripMailHeaderTokenizer extends Tokenizer {

  private static final long serialVersionUID = 2895675028020061928L;
  private boolean started;

  /**
   * Constructor to remove tokens from headers in the Enron data set
   */
  public EnronStripMailHeaderTokenizer() {
    this.started = false;
  }

  /**
   * Eliminates tokens from headers in the Enron data set
   */
  @Override
  public List<Token> tokenize(List<Token> tokens) {
    List<Token> tokenVector = Collections.synchronizedList(new Vector<Token>());
    synchronized (tokenVector) {
      for (Token token : tokens) {
        if (token.name().contains("X-FileName")) {
          this.started = true;
        }
        if (this.started) {
          if (!token.name().contains("X-FileName")) {
            StringTokenizer stringTokenizer = new StringTokenizer(token.name());
            while (stringTokenizer.hasMoreTokens()) {
              tokenVector.add(new Token(stringTokenizer.nextToken(), token.start_byte(), token.end_byte()));
            }
          }
        }
      }
      return tokenVector;
    }
  }
}
